==> apache-plc4x-0.6.0-source-release.zip: apache-plc4x-0.6.0/sandbox/code-gen/src/main/java/org/apache/plc4x/codegen/python/AttributeNode.java <==
/*
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
*/
package org.apache.plc4x.codegen.python;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonTypeName;

@JsonTypeName("Attribute")
public class AttributeNode extends LineEntryNode {

    @JsonProperty("attr")
    private String attr;

    @JsonProperty("ctx")
    private ContextNode ctx;

    @JsonProperty("value")
    private Node value;

    public String getAttr() {
        return attr;
    }

    public void setAttr(String attr) {
        this.attr = attr;
    }

    public ContextNode getCtx() {
        return ctx;
    }

    public void setCtx(ContextNode ctx) {
        this.ctx = ctx;
    }

    public Node getValue() {
        return value;
    }

    public void setValue(Node value) {
        this.value = value;
    }

    @Override public <T> T accept(NodeVisitor<T> visitor) {
        return visitor.visit(this);
    }
}

==> apache-plc4x-0.8.0-source-release.zip: apache-plc4x-0.8.0/sandbox/code-gen/src/main/java/org/apache/plc4x/codegen/python/AttributeNode.java <==
/*
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an
"AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied.  See the License for the
specific language governing permissions and limitations
under the License.
*/
package org.apache.plc4x.codegen.python;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonTypeName;

@JsonTypeName("Attribute")
public class AttributeNode extends LineEntryNode {

    @JsonProperty("attr")
    private String attr;

    @JsonProperty("ctx")
    private ContextNode ctx;

    @JsonProperty("value")
    private Node value;

    public String getAttr() {
        return attr;
    }

    public void setAttr(String attr) {
        this.attr = attr;
    }

    public ContextNode getCtx() {
        return ctx;
    }

    public void setCtx(ContextNode ctx) {
        this.ctx = ctx;
    }

    public Node getValue() {
        return value;
    }

    public void setValue(Node value) {
        this.value = value;
    }

    @Override
    public <T> T accept(NodeVisitor<T> visitor) {
        return visitor.visit(this);
    }
}
